@@ -1,13 +1,14 @@
+#include "../Common/Common.h"
 #include "EyetrackerFilter.h"
 
 #include <iostream>
 
 static SModuleSettings sSettings[] = {
-  {BP_AUTOCALIBRATE, T_BOOL, -1, -1, -1, -1, "Automatic calibration:"}
+  {BP_AUTOCALIBRATE, T_BOOL, -1, -1, -1, -1, _("Automatic calibration:")}
 };
 
 CEyetrackerFilter::CEyetrackerFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, CDasherModel *m_pDasherModel)
-  : CDefaultFilter(pEventHandler, pSettingsStore, pInterface, m_pDasherModel, 5, "Eyetracker Mode") {
+  : CDefaultFilter(pEventHandler, pSettingsStore, pInterface, m_pDasherModel, 5, _("Eyetracker Mode")) {
 
   // Setup some autocalibration parameters
   m_iYAutoOffset = 0;
