@@ -10,11 +10,11 @@ namespace Dasher {
   class CDasherInterfaceBase;
 }
 
-/// \defgroup Input Input filters
+/// \defgroup InputFilter Input filters
 /// @{
 class CInputFilter : public CDasherModule {
  public:
-  CInputFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase *pInterface, long long int iID, int iType, const char *szName)
+  CInputFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase *pInterface, ModuleID_t iID, int iType, const char *szName)
     : CDasherModule(pEventHandler, pSettingsStore, iID, iType, szName) {
     m_pInterface = pInterface;
   };
