@@ -11,10 +11,15 @@ class CPangoCache {
 public:
   CPangoCache(const std::string & strFontName);
   void ChangeFont(const std::string & strFontName);
-  PangoLayout *GetLayout(GtkWidget * pCanvas, std::string sDisplayText, int iSize);
+
+#if WITH_CAIRO
+  PangoLayout *GetLayout(cairo_t *cr, std::string sDisplayText, int iSize);
+#else
+  PangoLayout *GetLayout(GtkWidget *pCanvas, std::string sDisplayText, int iSize);
+#endif
 
 private:
-    std::map < std::string, PangoLayout * >oPangoCache;
+  std::map<std::string, PangoLayout *> oPangoCache;
   PangoFontDescription *font;
 };
 
